@@ -33,7 +33,7 @@ class Parameter():
             'param_form': self.param_form
         }
 
-    def verification(self, checking: dict, verify: dict, optional: dict = {}) -> bool:
+    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> bool:
         for opt_k, opt_v in optional.items():
             # 没有选填参数时，填充预设的默认值
             if not checking.__contains__(opt_k):
@@ -46,8 +46,12 @@ class Parameter():
             abort(Response(json.dumps(json_data), 400, {}))
         for _k, _v in checking.items():
             try:
+                str_data = None
+                if not null_value and len(_v) == 0 and verify[_k] == str:
+                    str_data = f'参数 {_k} 不能是空字符串'
                 if type(_v) != verify[_k]:
                     str_data = f'参数 {_k} 应该是 {verify[_k]} 类型'
+                if str_data:
                     logging.warning('请求参数类型校验失败: {0}'.format(str_data))
                     abort(Response(str_data, 400, {}))
             except KeyError as err:
